@@ -1,9 +1,10 @@
 import logging
-
+from pathlib import Path
+from subprocess import call
 from dynaconf import Dynaconf
 
 
-logger = logging.getLogger('dogsbody.utils')
+logger = logging.getLogger(__name__)
 
 
 DEFAULT_SETTING_FILES = ['/etc/dogsbody.toml', 'settings.toml']
@@ -34,3 +35,25 @@ def setup_logger(level=0, filename=None, root='', format_str='%(asctime)s - %(na
         fh.setLevel(level)
         local_logger.addHandler(fh)
     return local_logger
+
+
+def execute(path):
+    logger.info('Change to workdir.')
+
+    if Path(path / 'main.py').is_file():
+        try:
+            exec(Path(path / 'main.py').read_text(encoding='UTF-8'), globals())
+            logger.info('run the main.py file ...')
+        except Exception as e:
+            logger.warning('error in main.py "%s"', str(e))
+
+    elif Path(path / 'main.sh').is_file():
+        filename = str(Path(path / 'main.sh'))
+        call(['chmod', 'a+x', filename])
+        call([filename])
+        logger.info('run the main.sh file ...')
+
+    else:
+        logger.info('No main.sh file!')
+        return False
+    return True
